//
//  EMCircleChannel.h
//  HyphenateChat
//
//  Created by 冯钊 on 2022/6/16.
//  Copyright © 2022 easemob.com. All rights reserved.
//

#import <Foundation/Foundation.h>
/**
 *  \~chinese
 *  频道类型。
 */
typedef NS_ENUM(NSUInteger, EMCircleChannelType) {
    EMCircleChannelTypePublic = 0,      /* \~chinese 公开频道。 */
    EMCircleChannelTypePrivate,         /* \~chinese 私密频道。 */
};
/**
 *  \~chinese
 *  频道模式。
 */
typedef NS_ENUM(NSUInteger, EMCircleChannelMode) {
    EMCircleChannelModeChat = 0,      /* \~chinese 文字频道。 */
    EMCircleChannelModeVoice,         /* \~chinese 语聊频道。 */
};

NS_ASSUME_NONNULL_BEGIN

@interface EMCircleChannel : NSObject

- (instancetype)init NS_UNAVAILABLE;
+ (instancetype)new NS_UNAVAILABLE;

- (instancetype)initWithServerId:(NSString *)serverId channelId:(NSString *)channelId name:(NSString *)name;
/**
 *  \~chinese
 *  频道模式。详见 {@link EMCircleChannelMode}。
 */
@property (nonatomic, assign) EMCircleChannelMode mode;
/**
 *  \~chinese
 *  频道所属社区的 ID。
 */
@property (nonatomic, copy) NSString *serverId;

/**
 *  \~chinese
 *  频道所属分组的 ID。
 */
@property (nonatomic, copy) NSString *categoryId;

/**
 *  \~chinese
 *  频道 ID。
 */
@property (nonatomic, copy) NSString *channelId;
/**
 *  \~chinese
 *  频道名称。
 */
@property (nonatomic, copy) NSString *name;
/**
 *  \~chinese
 *  频道描述。
 */
@property (nonatomic, copy, nullable) NSString *desc;
/**
 *  \~chinese
 *  频道自定义扩展字段。
 */
@property (nonatomic, copy, nullable) NSString *ext;
/**
 *  \~chinese
 *  是否是社区中的默认频道：
 *  - `YES`：是；
 *  - `NO`：否。
 */
@property (nonatomic, assign) BOOL isDefault;
/**
 *  \~chinese
 *  频道的类型。详见 {@link EMCircleChannelType}。
 */
@property (nonatomic, assign) EMCircleChannelType type;
/**
 *  \~chinese
 *  频道的最大成员数量。
 *  - 对于语聊频道，该属性的取值范围为 [1,20]，默认值为 `8`。
 *  - 对于文字频道，该属性的取值范围为 [1,2000]，默认值为 `2000`。
 */
@property (nonatomic, assign) int32_t maxUsers;

@end

NS_ASSUME_NONNULL_END
