//
//  EMCircleManagerServerDelegate.h
//  HyphenateChat
//
//  Created by 冯钊 on 2022/6/28.
//  Copyright © 2022 easemob.com. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "EMCircleServerEvent.h"
#import "EMCircleUser.h"
#import "EMCircleServer.h"

NS_ASSUME_NONNULL_BEGIN

@protocol EMCircleManagerServerDelegate <NSObject>
@optional

/**
 *  \~chinese
 *  有新社区创建。
 *
 *  @param server  创建的社区对象。
 */
- (void)onServerCreated:(EMCircleServer *)server;
/**
 *  \~chinese
 *  社区被销毁。
 *  
 *  社区所有成员（除社区所有者）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param initiator 操作者的用户 ID。
 */
- (void)onServerDestroyed:(NSString *)serverId initiator:(NSString *)initiator;

/**
 *  \~chinese
 *  社区信息变更。
 *  
 *  社区的所有成员（除操作者外）会收到该事件。
 *
 *  @param event  变更事件。
 */
- (void)onServerUpdated:(EMCircleServerEvent *)event;

/**
 *  \~chinese
 *  用户加入社区。
 * 
 *  社区所有成员（除加入社区的新成员外）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param member    新成员的用户 ID。
 */
- (void)onMemberJoinedServer:(NSString *)serverId member:(NSString *)member;

/**
 *  \~chinese
 *  用户主动退出社区。
 * 
 *  社区内其他成员会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param member    退出社区的用户 ID。
 */
- (void)onMemberLeftServer:(NSString *)serverId member:(NSString *)member;

/**
 *  \~chinese
 *  用户被移出社区。
 * 
 *  被移出社区的成员、社区所有者和管理员（除操作者外）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param members   被移出社区的用户 ID 集合。
 */
- (void)onMemberRemovedFromServer:(NSString *)serverId members:(NSArray<NSString *> *)members;

/**
 *  \~chinese
 *  收到社区邀请。
 * 
 *  受邀人会收到该事件。
 * 
 *  @param event  社区 ID。
 *  @param inviter   邀请人的用户 ID。
 */
- (void)onReceiveServerInvitation:(EMCircleServerEvent *)event inviter:(NSString *)inviter;

/**
 *  \~chinese
 *  接受社区加入邀请。
 *
 *  邀请人会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param invitee   受邀人的用户 ID。
 */
- (void)onServerInvitationBeAccepted:(NSString *)serverId invitee:(NSString *)invitee;

/**
 *  \~chinese
 *  拒绝社区邀请。
 *
 *  邀请人会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param invitee   受邀人的用户 ID。
 */
- (void)onServerInvitationBeDeclined:(NSString *)serverId invitee:(NSString *)invitee;

/**
 *  \~chinese
 *  社区成员的角色发生变化。
 *
 *  社区所有成员（除操作者外）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param member    角色发生变更的成员的用户 ID。
 *  @param roleId    成员的新角色。详见 {@link EMCircleUserRole}。
 */
- (void)onServerRoleAssigned:(NSString *)serverId member:(NSString *)member role:(EMCircleUserRole)role;

@end

NS_ASSUME_NONNULL_END
