//
//  EMCircleManagerCategoryDelegate.h
//  HyphenateChat
//
//  Created by 冯钊 on 2022/12/19.
//  Copyright © 2022 easemob.com. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "EMCircleCategory.h"

NS_ASSUME_NONNULL_BEGIN

@protocol EMCircleManagerCategoryDelegate <NSObject>
@optional

/**
 *  \~chinese
 *  社区内创建了新频道分组。
 *  
 *  社区所有成员（除频道分组的创建者外）会收到该事件。
 *
 *  @param category  新的频道分组对象。
 *  @param creator   频道分组创建者的用户 ID。
 */
- (void)onCategoryCreated:(EMCircleCategory *)category creator:(NSString *)creator;

/**
 *  \~chinese
 *  社区内删除了频道分组。
 *
 *  社区所有成员（除操作者外）会收到该事件。
 *
 *  @param serverId    社区 ID。
 *  @param categoryId  频道分组 ID。
 *  @param initiator   操作者的用户 ID。
 */
- (void)onCategoryDestroyed:(NSString *)serverId categoryId:(NSString *)categoryId initiator:(NSString *)initiator;

/**
 *  \~chinese
 *  社区内修改了频道分组名称。
 *
 *  社区所有成员（除操作者外）会收到该事件。
 *
 *  @param category   更新的频道分组对象。
 *  @param initiator  操作者的用户 ID。
 */
- (void)onCategoryUpdated:(EMCircleCategory *)category initiator:(NSString *)initiator;

/**
 *  \~chinese
 *  频道从一个频道分组转移至另一个分组。
 *
 *  社区所有成员（除操作者外）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param from  原频道分组 ID。
 *  @param to  目标频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param initiator  操作者的用户 ID。
 */
- (void)onChannelTransferred:(NSString *)serverId from:(NSString *)fromCategoryId to:(NSString *)toCategoryId channelId:(NSString *)channelId initiator:(NSString *)initiator;

@end

NS_ASSUME_NONNULL_END
