//
//  EMCircleManagerChannelDelegate.h
//  HyphenateChat
//
//  Created by 冯钊 on 2022/6/28.
//  Copyright © 2022 easemob.com. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "EMCircleChannelExt.h"
#import "EMCircleUser.h"
#import "EMCircleChannel.h"

NS_ASSUME_NONNULL_BEGIN

@protocol EMCircleManagerChannelDelegate <NSObject>

@optional
/**
 *  \~chinese
 *  社区内创建了新频道。
 *
 *  参与频道创建的初始成员会收到该事件。
 *
 *  @param channel  新创建的频道对象。
 *  @param creator  频道创建者的用户 ID。
 */
- (void)onChannelCreated:(EMCircleChannel *)channel creator:(NSString *)creator;

/**
 *  \~chinese
 *  社区内的频道被销毁。
 * 
 *  频道的所有成员（除操作者）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param initiator  操作者的用户 ID。
 */
- (void)onChannelDestroyed:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId initiator:(NSString *)initiator;

/**
 *  \~chinese
 *  社区内修改了频道信息。
 * 
 *  频道所有成员（除操作者外）会收到该事件。
 * 
 *  @param channel  修改后的频道对象。
 *  @param initiator  操作者的用户 ID。
 */
- (void)onChannelUpdated:(EMCircleChannel *)channel initiator:(NSString *)initiator;

/**
 *  \~chinese
 *  有用户加入频道。
 *
 *  频道的所有成员（不包括该新加入的成员）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param member  新成员的用户 ID。
 */
- (void)onMemberJoinedChannel:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId member:(EMCircleUser *)member;

/**
 *  \~chinese
 *  成员主动退出频道。
 *  
 *  频道内的其他成员会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param member  退出频道的成员的用户 ID。
 */
- (void)onMemberLeftChannel:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId member:(NSString *)member;

/**
 *  \~chinese
 *  成员被移出频道。
 *
 *  被移出的成员会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param member  被踢出成员的用户 ID。
 *  @param initiator  操作者的用户 ID。
 */
- (void)onMemberRemovedFromChannel:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId member:(NSString *)member initiator:(NSString *)initiator;

/**
 *  \~chinese
 *  收到加入频道的邀请。
 * 
 *  受邀人会收到该事件。
 *
 *  @param channelId  频道 ID。
 *  @param inviter  邀请人的用户 ID。
 */
- (void)onReceiveChannelInvitation:(EMCircleChannelExt *)invite inviter:(NSString *)inviter;

/**
 *  \~chinese
 *  接受频道加入邀请。
 *  
 *  邀请人会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param invitee  受邀人的用户 ID。
 */
- (void)onChannelInvitationBeAccepted:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId invitee:(NSString *)invitee;

/**
 *  \~chinese
 *  拒绝频道加入邀请。
 * 
 *  邀请人会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param invitee  受邀人的用户 ID。
 */
- (void)onChannelInvitationBeDeclined:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId invitee:(NSString *)invitee;

/**
 *  \~chinese
 *  频道成员的禁言状态变更。
 * 
 *  禁言状态变更的成员及社区所有者和管理员（除操作者外）会收到该事件。
 *
 *  @param serverId  社区 ID。
 *  @param categoryId 频道分组 ID。
 *  @param channelId  频道 ID。
 *  @param muted  是否禁言：
 *                - `YES`：是；
 *                - `NO`：否。
 *  @param members  禁言状态变更的成员的用户 ID 列表。
 */
- (void)onMemberMuteChangeInChannel:(NSString *)serverId categoryId:(NSString *)categoryId channelId:(NSString *)channelId muted:(BOOL)isMuted members:(NSArray<NSString *> *)members;

@end

NS_ASSUME_NONNULL_END
