//
//  EMCircleServer.h
//  HyphenateChat
//
//  Created by 冯钊 on 2022/6/15.
//  Copyright © 2022 easemob.com. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "EMCircleServerTag.h"
/**
 *  \~chinese
 *  社区类型：
 *  - Public：公开社区；
 *  - Private：私密社区。
 */
typedef NS_ENUM(NSUInteger, EMCircleServerType) {
    EMCircleServerTypePublic = 0,
    EMCircleServerTypePrivate,
};

NS_ASSUME_NONNULL_BEGIN

@interface EMCircleServer : NSObject

- (instancetype)init NS_UNAVAILABLE;
+ (instancetype)new NS_UNAVAILABLE;

- (instancetype)initWithServerId:(NSString *)serverId name:(NSString *)name defaultChannelId:(NSString *)channelId;
/**
 *  \~chinese
 *  社区类型。详见 {@link EMCircleServerType}。
 */
@property (nonatomic, assign) EMCircleServerType type;

/**
 *  \~chinese
 *  社区 ID。
 */
@property (nonatomic, copy) NSString *serverId;
/**
 *  \~chinese
 *  社区名称。
 */
@property (nonatomic, copy) NSString *name;
/**
 *  \~chinese
 *  社区头像。
 */
@property (nonatomic, copy, nullable) NSString *icon;
/**
 *  \~chinese
 *  社区背景。
 */
@property (nonatomic, copy, nullable) NSString *background;
/**
 *  \~chinese
 *  社区描述。
 */
@property (nonatomic, copy, nullable) NSString *desc;
/**
 *  \~chinese
 *  社区的自定义扩展信息。
 */
@property (nonatomic, copy, nullable) NSString *ext;
/**
 *  \~chinese
 *  社区的所有者。
 */
@property (nonatomic, copy, nullable) NSString *owner;
/**
 *  \~chinese
 *  社区中默认频道的 ID。
 */
@property (nonatomic, copy) NSString *defaultChannelId;
/**
 *  \~chinese
 *  社区标签。
 */
@property (nonatomic, strong, nullable) NSArray<EMCircleServerTag *> *tags;

@end

NS_ASSUME_NONNULL_END
